"use strict";

const { images_url } = require("../../../constants");
const WebPage = require("../../lib/web-page");

const EDU_THEMES = [
    // {
    //     title: "Création de jeux vidéo",
    //     description: "Conception, graphisme et animation, programmation, je vous accompagne dans la découverte des techniques pour créer un jeu vidéo de A à Z",
    //     image: "learning_theme_conception.png",
    //     pageUrl: "gamedev",
    // },
    {
        title: "Programmation",
        description: `<b>Franchissez le mur du code !</b><br />
        Apprenez à programmer avec différents langages (Python, Javascript, C ...), pour du web, du logiciel, du jeu vidéo ou autre.`,
        image: "learning_theme_coding.png",
        // pageUrl: "coding",
    },
    {
        title: "Dessin numérique et animation 2D",
        description: `Apprenez à utiliser des logiciels libres de création graphique 2D et d'animation.<br />
        Créez des personnages et des décors, menez votre projet de dessin animé, d'illustration ou de jeu vidéo.`,
        image: "learning_theme_2d.png",
        // pageUrl: "2d",
    },
    {
        title: "Maths et physiques",
        description: "Abordez les notions fondamentales de façon décontractée pour le plaisir de comprendre.",
        image: "learning_theme_math.png",
        // pageUrl: "math",
    },
    // {
    //     title: "Musique et sons électroniques",
    //     description: "Découvrez des logiciels libres de composition musicales, de synthèse sonore et de prise de son.",
    //     image: "learning_theme_sound.png",
    //     pageUrl: "sound",
    // },
    {
        title: "Aide informatique générale",
        description: "Perdu avec votre ordinateur ou votre smartphone, les logiciels, internet ? Je vous aide pas à pas à comprendre les fondamentaux et à utiliser sereinement la technologie.",
        image: "learning_theme_pc.png",
        // pageUrl: "popularization"
    }
];

class EducationPage extends WebPage {
    render() {
        return {
            tag: "div",
            id: "education-page",
            typeof: "EducationalOrganization",
            contents: [
                {
                    tag: "div",
                    class: "page-header logo-left",
                    contents: [
                        {
                            tag: "div",
                            class: "page-contents-center grid-wrapper",
                            contents: [
                                {
                                    tag: "div",
                                    class: "logo",
                                    contents: [
                                        {
                                            tag: "img",
                                            alt: "image brain",
                                            src: `${images_url}brain.svg`,
                                        },
                                    ],
                                },
                                { tag: "h1", contents: "Pédagogie" },
                                {
                                    tag: "p",
                                    contents: `Animation d'ateliers informatiques accessibles à tous. 
                                    Programmation, graphisme 2D, jeux vidéo, vulgarisation, accompagnement de projet, etc.`,
                                },
                            ],
                        },
                    ],
                },
                {
                    tag: "div",
                    class: "title-banner",
                },
                {
                    tag: "section",
                    class: "bg-dark",
                    contents: [
                        {
                            tag: "div",
                            class: "page-contents-center",
                            contents: [
                                {
                                    tag: "ul",
                                    class: "edu-themes",
                                    contents: EDU_THEMES.map(theme => {
                                        return {
                                            tag: "li",
                                            class: "edu-theme",
                                            contents: [
                                                { tag: "img", width: 250, height: 140, class: "pixelated", src: `${images_url}${theme.image}` },
                                                { tag: "h3", contents: theme.title },
                                                { tag: "p", contents: theme.description },
                                            ]
                                        }
                                    })
                                },
                            ]
                        },
                    ]
                },
                {
                    tag: "section",
                    class: "practical-info",
                    contents: [
                        {
                            tag: "div",
                            class: "page-contents-center",
                            contents: [
                                {
                                    tag: "div",
                                    class: "info-block",
                                    contents: [
                                        { tag: "h3", class: "info-title", contents: "Pour qui ?" },
                                        {
                                            tag: "p",
                                            class: "info-body",
                                            contents: `Les ateliers sont accessibles aux adultes comme aux enfants, plutôt à partir de 12 ans.<br/>
                                            Les séances ont lieu en groupes mixtes.
                                            `
                                        }
                                    ]
                                },
                                {
                                    tag: "div",
                                    class: "info-block",
                                    contents: [
                                        { tag: "h3", class: "info-title", contents: "Où ça ?" },
                                        {
                                            tag: "p",
                                            class: "info-body",
                                            contents: "Dans mon local professionnel : <br /><blue>32 rue Simon Vialet, passage du Cheminou, 07240 Vernoux en Vivarais.</blue>"
                                        }
                                    ]
                                },
                                {
                                    tag: "div",
                                    class: "info-block",
                                    contents: [
                                        { tag: "h3", class: "info-title", contents: "Quel matériel ?" },
                                        {
                                            tag: "p",
                                            class: "info-body",
                                            contents: `Le matériel informatique est fourni sur place (ordinateurs et tablettes graphique) 
                                            mais il est possible d'amener le sien. 
                                            <br />Il est recommandé d'apporter au moins une clé USB pour faire ses sauvegardes.`
                                        }
                                    ]
                                },
                                {
                                    tag: "div",
                                    class: "info-block",
                                    contents: [
                                        { tag: "h3", class: "info-title", contents: "Quand ?" },
                                        {
                                            tag: "ul",
                                            class: "info-body tabled",
                                            contents: [
                                                {
                                                    tag: "li",
                                                    contents: [
                                                        { tag: "span", contents: "Mardi" },
                                                        { tag: "span", contents: "16h - 18h" },
                                                    ]
                                                },
                                                {
                                                    tag: "li",
                                                    contents: [
                                                        { tag: "span", contents: "Mercredi" },
                                                        { tag: "span", contents: "14h - 16h" },
                                                    ]
                                                },
                                                {
                                                    tag: "li",
                                                    contents: [
                                                        { tag: "span", contents: "Jeudi" },
                                                        { tag: "span", contents: "16h - 18h" },
                                                    ]
                                                },
                                                {
                                                    tag: "li",
                                                    class: "fullwidth",
                                                    contents: "<em><blue>Ouvert de Septembre à Juin, sauf vacances scolaires ou fermetures exceptionnelles</blue></em>"
                                                }
                                            ]
                                        },
                                    ]
                                },
                                {
                                    tag: "div",
                                    class: "info-block",
                                    contents: [
                                        { tag: "h3", class: "info-title", contents: "Combien ça coûte ?" },
                                        {
                                            tag: "ul",
                                            class: "info-body tabled",
                                            contents: [
                                                {
                                                    tag: "li",
                                                    contents: [
                                                        { tag: "span", contents: "Inscription au mois" },
                                                        { tag: "span", contents: "50€" },
                                                    ]
                                                },
                                                {
                                                    tag: "li",
                                                    contents: [
                                                        { tag: "span", contents: "Inscription à la séance" },
                                                        { tag: "span", contents: "15€" },
                                                    ]
                                                },
                                                {
                                                    tag: "li",
                                                    contents: [
                                                        { tag: "span", contents: "Cours particuliers" },
                                                        { tag: "span", contents: "30€/h, sur place ou en visio. Horaires à définir." },
                                                    ]
                                                }
                                            ]
                                        }
                                    ]
                                },
                                {
                                    tag: "div",
                                    class: "info-block",
                                    contents: [
                                        { tag: "h3", class: "info-title", contents: "Pour s'inscrire ou en savoir plus" },
                                        {
                                            tag: "ul",
                                            class: "info-body",
                                            contents: [
                                                {
                                                    tag: "li",
                                                    contents: [
                                                        { tag: "span", contents: "Me contacter" },
                                                        {
                                                            tag: "a",
                                                            href: "mailto:contact@kuadrado-software.fr",
                                                            contents: "contact@kuadrado-software.fr",
                                                        }
                                                    ]
                                                },
                                                {
                                                    tag: "li",
                                                    contents: [
                                                        { tag: "span", contents: "" },
                                                        {
                                                            tag: "a",
                                                            href: "tel:+33475780872",
                                                            contents: "04 75 78 08 72",
                                                            property: "telephone",
                                                        },
                                                    ]
                                                },
                                                {
                                                    tag: "li",
                                                    contents: [
                                                        { tag: "span", contents: "ou passer directement me voir au local !" }
                                                    ]
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]

                },
            ],
        };
    }
}

module.exports = EducationPage;
